@@ -114,16 +114,16 @@ endpoints = {
         "endpoint": "/api/v1/aggregation"
 
     },
-    "visitor_history": {
-        "method": "GET",
-        "endpoint": "/api/v1/visitor/{visitorId}/history",
-        "headers": {
-            'content-type': 'application/x-www-form-urlencoded'
-        },
-        "params": {
-            "starttime": "1564056526000"
-        }
-    },
+    # "visitor_history": {
+    #     "method": "GET",
+    #     "endpoint": "/api/v1/visitor/{visitorId}/history",
+    #     "headers": {
+    #         'content-type': 'application/x-www-form-urlencoded'
+    #     },
+    #     "params": {
+    #         "starttime": "1564056526000"
+    #     }
+    # },
     "track_types": {
         "method": "POST",
         "endpoint": "/api/v1/aggregation"
@@ -863,33 +863,33 @@ class MetadataVisitor(Stream):
             yield (self.stream, report)
 
 
-class VisitorHistory(Stream):
-    name = "visitor_history"
-    replication_method = "INCREMENTAL"
-    replication_key = "last_ts"
-    key_properties = ['visitor_id']
-    DATE_WINDOW_SIZE = 1
+# class VisitorHistory(Stream):
+#     name = "visitor_history"
+#     replication_method = "INCREMENTAL"
+#     replication_key = "last_ts"
+#     key_properties = ['visitor_id']
+#     DATE_WINDOW_SIZE = 1
 
-    def get_params(self, start_time):
-        return {"starttime": start_time}
+#     def get_params(self, start_time):
+#         return {"starttime": start_time}
 
-    def sync(self, state, start_date=None, key_id=None):
-        update_currently_syncing(state, self.name)
+#     def sync(self, state, start_date=None, key_id=None):
+#         update_currently_syncing(state, self.name)
 
-        abs_start, abs_end = get_absolute_start_end_time(start_date)
-        lookback = abs_start - timedelta(days=self.lookback_window())
-        window_next = lookback
+#         abs_start, abs_end = get_absolute_start_end_time(start_date)
+#         lookback = abs_start - timedelta(days=self.lookback_window())
+#         window_next = lookback
 
-        while window_next <= abs_end:
-            ts = int(window_next.timestamp()) * 1000
-            params = self.get_params(start_time=ts)
-            visitor_history = self.request(endpoint=self.name,
-                                           params=params,
-                                           visitorId=key_id)
-            for visitor in visitor_history:
-                visitor['visitorId'] = key_id
-                yield visitor
-            window_next = window_next + timedelta(days=self.DATE_WINDOW_SIZE)
+#         while window_next <= abs_end:
+#             ts = int(window_next.timestamp()) * 1000
+#             params = self.get_params(start_time=ts)
+#             visitor_history = self.request(endpoint=self.name,
+#                                            params=params,
+#                                            visitorId=key_id)
+#             for visitor in visitor_history:
+#                 visitor['visitorId'] = key_id
+#                 yield visitor
+#             window_next = window_next + timedelta(days=self.DATE_WINDOW_SIZE)
 
 
 class Visitors(Stream):
@@ -992,7 +992,7 @@ STREAMS = {
     "features": Features,
     "guides": Guides,
     "pages": Pages,
-    "visitor_history": VisitorHistory,
+    # "visitor_history": VisitorHistory,
     "visitors": Visitors,
     "feature_events": FeatureEvents,
     "events": Events,
@@ -1006,7 +1006,7 @@ STREAMS = {
 }
 
 SUB_STREAMS = {
-    'visitors': 'visitor_history',
+    # 'visitors': 'visitor_history',
     'features': 'feature_events',
     'pages': 'page_events',
     'guides': 'guide_events',
